engineParams function.NlmeEngineExtraParams : Defines all engine parameters for NLME models
Wrapped up by engineParams function.
isPopulationlogical; TRUE if the model is a population model, FALSE for an individual model.
sortcharacter; String to pass sorting options to the NLME engine. Typically " -sort " to enable sorting or "" to disable it.
csvcharacter; String to control CSV input options. Typically " -csv " to strict the input data to comma-separated-values. Use "" to disable it (NLME will try to guess the input format).
methodnumeric; Integer code specifying the estimation method.
1: QRPEM
2: IT2S-EM
3: FOCE-LB
4: FO
5: FOCE-ELS/LAPLACIAN (see below for choice between FOCE-ELS and LAPLACIAN)
6: NAIVE-POOLED
The choice between FOCE-ELS and LAPLACIAN (when method is 5) depends
on the xfocehess slot: xfocehess = 1 selects FOCE-ELS, and
xfocehess = 0 selects LAPLACIAN.
numIterationsnumeric; The maximum number of iterations allowed for the estimation algorithm. Values must be non-negative integers.
odeToUsenumeric; Integer code specifying the ODE solver to be used. Possible values are:
1: LSODE with numerical Jacobian
2: LSODE with analytical Jacobian
3: Runge-Kutta
4: LSODA with numerical Jacobian
5: LSODA with analytical Jacobian
6: Matrix Exponent
7: DOPRI5
rtolnumeric; Specifies the relative tolerance for the ODE solver.
atolnumeric; Specifies the absolute tolerance for the ODE solver.
nmxstepnumeric; Specifies the maximum number of steps allowed for the ODE solver.
anagradnumeric; Flag controlling the differentiation method used during the optimization of random effects (etas). 0 uses a finite difference approach, and 1 uses automatic differentiation where possible.
xnpnumeric; Controls the use of non-parametric (NP) optimization.
0: No NP optimization.
1: NONMEM-style NP optimization using posthoc estimates as support points.
>1: Evolutionary NP algorithm with xnp generations.
xnorderagqnumeric; Specifies the number of quadrature points per
dimension for Adaptive Gaussian Quadrature (AGQ). Only applicable when
method is FOCE-ELS or LAPLACIAN.
1: Standard FOCE-ELS/LAPLACIAN computation (no AGQ).
>1: AGQ is performed. The total number of quadrature points used is (number of ETAs)^xnorderagq.
xfocehessnumeric; Determines the method for calculating the Hessian matrix when using FOCE methods.
0: Use numerical second derivatives.
1: Use the FOCE approximation.
Applicable only when method is FOCE-ELS or LAPLACIAN.
xstderrnumeric; Specifies the method for standard error estimation.
0: No standard error estimation.
1: Central difference method.
2: Forward difference method.
sandcharacter; String to request sandwich standard error calculation. Typically " -sand " or "".
fishercharacter; String to request Fisher score standard error calculation. Typically " -fscore " or "".
autodetectcharacter; String to request auto-detection of standard error method. Typically " -AutoSE " or "".
xlandignumeric; Specifies the optimization accuracy (NDIGIT) for the
outer loop (thetas and sigmas) when using FOCE-ELS or
LAPLACIAN methods.
xlatolnumeric; Specifies the relative step size used for numerical computation of the Hessian matrix (second derivatives) during standard error calculation.
xblndignumeric; Specifies the optimization accuracy (NDIGIT) for the
inner loop (optimization of etas). Also applies to the single optimization
loop in the NAIVE-POOLED method.
xbltolnumeric; Specifies the relative step size for numerical differentiation during model linearization.
gradTolOuterNumeric maximum gradient tolerance in the outer
(Theta/Omega/Sigma) optimization loop. Applicable to FOCE-ELS and
LAPLACIAN methods.
stepTolOuterNumeric maximum step tolerance in the outer
(Theta/Omega/Sigma) optimization loop. Applicable to FOCE-ELS and
LAPLACIAN methods.
gradTolInnerNumeric maximum gradient tolerance in the inner (Eta)
optimization loop. Applicable to FOCE-ELS and
LAPLACIAN methods.
stepTolInnerNumeric maximum step tolerance in the inner (Eta)
optimization loop. Applicable to FOCE-ELS and
LAPLACIAN methods.
refDeltaLaglNumeric LL Delta tolerance value used during
Theta/Omega/Sigma optimization. Applicable to FOCE-ELS and
LAPLACIAN methods.
isPCWRESnumeric; Flag indicating if Population Conditional Weighted Residuals (PCWRES) should be computed. A value of 1 indicates computation, while 0 indicates no computation. Only applicable to population models.
xpcwresnrepnumeric; Stores the number of simulation replicates used
for PCWRES computation. Applicable only when isPCWRES is 1.
xisamplenumeric; Specifies the number of sample points used in the
QRPEM algorithm. Only applicable when method is QRPEM.
xmapassistnumeric; Controls the use of MAP assistance in the QRPEM algorithm.
0: No MAP assistance.
>0: The inner ETAs optimization loop is used in the QRPEM outer
optimization loop with a periodicity equal to the value of xmapassist.
Only applicable when method is QRPEM.
xmapnpnumeric; Specifies the number of iterations for a preliminary
Naive-Pooled optimization run before the main estimation. Applicable when
the method is not NAIVE-POOLED.
ximpsampdofnumeric; Controls the importance sampling distribution used
in the QRPEM algorithm. Only applicable when method is QRPEM.
0: Multivariate Normal distribution.
1: Multivariate Double Exponential (Laplace) distribution.
2: Direct sampling from the prior.
3-30: Multivariate T distribution with degrees of freedom equal to the value of ximpsampdof.
-2: Mixture-2 distribution.
-3: Mixture-3 distribution.
xmcpemnumeric; Controls the sampling method used in the QRPEM algorithm.
0: Quasi-Random sampling.
1: Monte-Carlo sampling.
Only applicable when method is QRPEM.
xpemrunallnumeric; Set to 1 to execute all requested
iterations specified in numIterations. Only applicable to population
models with method = "QRPEM".
xsirsampnumeric; Specifies the number of samples per eta per subject
used in the Sampling Importance Resampling (SIR) algorithm within QRPEM.
Only applicable when method is QRPEM.
xburninnumeric; Specifies the number of burn-in iterations in the
QRPEM algorithm. During burn-in, omegas can be frozen (see
xnonomegaburn). Only applicable when method is QRPEM.
xnonomegaburnnumeric; Controls whether omegas are frozen during the burn-in phase of the QRPEM algorithm.
0: burn-in with frozen omegas is off.
1: burn-in with frozen omegas is on.
Only applicable when method is QRPEM. See also
xburnin.
xaccrationumeric; Specifies the acceptance ratio used in the QRPEM
algorithm for scaling the covariance matrix. Only applicable when
method is QRPEM. Only applicable to population models with
method = "QRPEM".
xscramblenumeric; Specifies the scrambling method for quasi-random number generation in the QRPEM algorithm.
0: No scrambling.
1: Owen-type scrambling.
2: Faure-Tezuka scrambling.
Only applicable when method is QRPEM.
emTolTypeNumeric specifying QRPEM convergence check type:
Default (no rollout, LL & Thetas)
LL & Params with rollout
LL with rollout
Params with rollout
Only applicable when method is QRPEM.
emConvLenNumeric specifying the number of iterations to check for
convergence. Only applicable when method is QRPEM.
emConvCritValNumeric specifying the convergence critical value. Only
applicable when method is QRPEM.
pardernnumeric; Specifies the number of time steps used for outputting partial derivatives of observed variables with respect to parameters. Only applicable to individual models.
parderdnumeric; Specifies the step size for numerical calculation of partial derivatives of observed variables with respect to parameters. Only applicable to individual models.
logtrannumeric; Engine flag controlling log-transformation behavior for single LogAdditive error model.
[engineParams()]
param <- NlmeEngineExtraParams(
method = 3,
numIterations = 1000
)
param <- NlmeEngineExtraParams(
method = 1,
numIterations = 300
)
param <- NlmeEngineExtraParams(
method = 1,
numIterations = 300,
isPopulation = TRUE,
odeToUse = 2
)
Run the code above in your browser using DataLab