This class defines an NLME parallel host, which can be either local or remote, for running jobs.
sharedDirectorycharacter. The directory where the run will take place.
On Windows, UNC paths are mapped to a drive letter for local execution.
installationDirectorycharacter. The directory containing NLME
libraries and scripts.
hostNamecharacter. A user-friendly name for the host (e.g., "local_mpi").
machineNamecharacter. The IP address or hostname of the machine.
Defaults to the local system's node name.
hostTypecharacter. The operating system of the host, either
"windows" or "linux". For remote Linux systems, you can specify a
supported distribution (e.g., "RHEL", "UBUNTU") to configure the
PML_BIN_DIR environment variable. linux will be treated as "RHEL".
numCoresnumeric. The number of compute cores to be used.
isLocallogical. TRUE if the host is local, FALSE if remote.
rLocationcharacter. The path to the Rscript executable on a remote
host. This is ignored for local runs.
scriptPathcharacter. The path to a script to execute on the remote
host before Rscript is started. This is ignored for local runs.
userAuthenticationNlmeUserAuthentication. An object containing user
credentials for remote host authentication. See NlmeUserAuthentication().
parallelMethodNlmeParallelMethod. The parallel computing method to
use (e.g., "LOCAL_MPI", "SGE", "TORQUE"). See NlmeParallelMethod().
host <- hostParams(
parallelMethod = "LOCAL_MPI",
hostName = "local_mpi",
numCores = 4
)
Run the code above in your browser using DataLab