Learn R Programming

Certara.RsNLME (version 3.1.0.1)

acceptAllEffects: Accepts all estimates for fixed effects, Sigma, and random effects

Description

Updates PML statements in model object with estimates returned from model execution. Use copyModel and set argument acceptAllEffects = TRUE to create new model object with final estimates from base model run.

Usage

acceptAllEffects(model)

Value

NlmePmlModel object

Arguments

model

Model object

See Also

copyModel

Examples

Run this code
if (FALSE) {
# Define the model
model <- pkmodel(numComp = 1,
                 absorption = "Intravenous",
                 ID = "Subject",
                 Time = "Act_Time",
                 CObs = "Conc",
                 A1 = "Amount",
                 data = pkData,
                 modelName = "PkModel",
                 workingDir = tempdir())

# Fit model
res <- fitmodel(model = model,
                hostPlatform = hostParams(sharedDirectory = tempdir()))
model <- acceptAllEffects(model)
}

Run the code above in your browser using DataLab