Learn R Programming

Certara.RsNLME (version 3.1.0.1)

addReset: Adds reset instructions to the model

Description

Adds reset instructions to the model

Usage

addReset(.Object, low, hi, Reset = NULL)

# S4 method for NlmePmlModel addReset(.Object, low, hi, Reset = NULL)

Value

Depends on the specific methods

Returns the 'NlmePmlModel' object with updated reset information and definitions.

Arguments

.Object

An 'NlmePmlModel' object to which you want to add reset instructions.

low

Lower value of reset range.

hi

Upper value of reset range.

Reset

Name of reset column in input data set for column mapping. The default is NULL.

Functions

  • addReset(NlmePmlModel): Method for the 'NlmePmlModel' class

    This method adds reset instructions to the NlmePmlModel object. It updates the reset information, checks column mappings if input data is not null, and adds a reset definition to user-defined extra definitions.