Learn R Programming

Certara.RsNLME (version 3.1.0.1)

addSecondary: Adds a secondary parameter to model definition

Description

Adds a secondary parameter to model definition

Usage

addSecondary(.Object, name, definition, unit = "")

# S4 method for NlmePmlModel addSecondary(.Object, name, definition, unit = "")

Value

Depends on the specific methods

Returns the 'NlmePmlModel' object with the added secondary parameter.

Arguments

.Object

An 'NlmePmlModel' object to which you want to add a secondary parameter.

name

Name of the secondary parameter.

definition

Definition of secondary parameter.

unit

Optional units of the secondary parameter. The default is "".

Functions

  • addSecondary(NlmePmlModel): Method for the 'NlmePmlModel' class

    This method adds a secondary parameter to the NlmePmlModel object. It checks for duplicate parameter names, and if there is no duplicate, it adds the new secondary parameter to the object and updates the PML model.

Examples

Run this code
# \donttest{
model <- pkmodel(columnMap = FALSE,
                 absorption = "FirstOrder",
                 workingDir = tempdir())
model <- addSecondary(model, "Ke", "tvCl/tvV")
model <- addSecondary(
  model, "Tmax",
  "CalcTMax(tvA,tvCl/tvV)"
)
# }

Run the code above in your browser using DataLab