Generic function for cancelling a job
cancelJob(.Object)# S4 method for SimpleNlmeJob
cancelJob(.Object)
Depends on the specific methods
Prints the 'SimpleNlmeJob' object after attempting to cancel the job. No return value.
A 'SimpleNlmeJob' object that you want to cancel
cancelJob(SimpleNlmeJob): Method for cancelling a job of the 'SimpleNlmeJob' class
This method attempts to cancel a job of the 'SimpleNlmeJob' class. If the job is running on a local host or is not running in the background, it throws an error and does nothing. Otherwise, it uploads a 'STOP' command to the host's remote executor.