Learn R Programming

Certara.RsNLME (version 3.1.0.1)

createModelInfo: Parse the model and get the list of terms

Description

Calls TDL5 to parse the model and get the list of terms

Usage

createModelInfo(model, ForceRun = FALSE)

Value

List of model information

Arguments

model

Model object

ForceRun

Set to TRUE to force run

Examples

Run this code
if (FALSE) {
  model <- pkmodel(columnMap = FALSE,
                   workingDir = tempdir())
  createModelInfo(model)
}

Run the code above in your browser using DataLab