Learn R Programming

Certara.RsNLME (version 3.1.0.1)

create_model_from_metamodel: Use to create model object from parsed metamodel

Description

Define NlmePmlModel model class instance from metamodel blocks and creates NlmePmlModel model class from the given parsed metamodel. See Metamodel overview.

Usage

create_model_from_metamodel(mmdlfile, directoryToRun)

Value

a list with the resulted model class instance and engine parameters. If multiple ESTARGS/SIMARGS blocks are used, a list of estimation argument classes (NlmeEngineExtraParams()) and simulation argument classes (simParamsBlock) are returned.

Arguments

mmdlfile

File with metamodel description

directoryToRun

Directory where the results will be stored; if missing, a subfolder in the current directory with the model name given in parsedMetamodel will be created

See Also

run_metamodel()

Examples

Run this code
 if (FALSE) {
   ModelParamsList <-
     create_model_from_metamodel(
       mmdlfile = system.file("extdata/mmdlNoTime", "test.mmdl",
                              package = "Certara.RsNLME"),
       directoryToRun = tempdir())
 }

Run the code above in your browser using DataLab