Deletes a secondary parameter from the model
deleteSecondary(.Object, name)# S4 method for NlmePmlModel
deleteSecondary(.Object, name)
Depends on the specific methods
Returns the 'NlmePmlModel' object with the secondary parameter removed.
An 'NlmePmlModel' object from which you want to delete a secondary parameter.
Name of the secondary parameter to be deleted.
deleteSecondary(NlmePmlModel): Method for the 'NlmePmlModel' class
This method deletes a secondary parameter from the NlmePmlModel object. It searches for the parameter by name, and if it is found, it removes it from the object and updates the PML model.