Learn R Programming

Certara.RsNLME (version 3.1.0.1)

editModel: Directly edit PML text in model object

Description

Allows user to edit PML text in model object using internal text editor and return a new textual model containing the edited PML statements.

Usage

editModel(.Object)

Value

Modified NlmePmlModel object

Arguments

.Object

Model object

Examples

Run this code
# \donttest{
model <- pkmodel(columnMap = FALSE,
                 workingDir = tempdir())

if (FALSE) {
  # will open an additional window with the model text:
  newModel <- editModel(model)
}
# }

Run the code above in your browser using DataLab