Learn R Programming

Certara.RsNLME (version 3.1.0.1)

listCovariateEffectNames: Lists covariate effect names in the model

Description

This function lists the names of covariate effects in a provided pharmacokinetic/pharmacodynamic (PK/PD) model.

Usage

listCovariateEffectNames(.Object)

# S4 method for NlmePmlModel listCovariateEffectNames(.Object)

Value

A vector of character strings containing the names of the covariate effects in the model.

Arguments

.Object

PK/PD model

Examples

Run this code
# \donttest{
model <- pkmodel(
  numCompartments = 2,
  data = pkData,
  ID = "Subject",
  Time = "Act_Time",
  A1 = "Amount",
  CObs = "Conc",
  workingDir = tempdir()
)
model <- addCovariate(model,
  covariate = "Gender",
  type = "Categorical",
  effect = c("V2", "Cl2"),
  levels = c(0, 1),
  labels = c("Female", "Male")
)
listCovariateEffectNames(model)
# }

Run the code above in your browser using DataLab