Learn R Programming

Certara.RsNLME (version 3.1.0.1)

loadModel: Load model.rda file

Description

Loads a previously saved model from disk.

Usage

loadModel(directory)

Value

No value is returned. Model object is loaded in global environment.

Arguments

directory

Directory where the model was saved

Details

Note, the names of model, engine, and host objects will be appended with name of model directory when reloading model.rda file to global environment.

Examples

Run this code
# \donttest{
TempDir <- tempdir()
model <- emaxmodel(
  checkBaseline = TRUE,
  checkFractional = TRUE,
  checkInhibitory = TRUE,
  data = pkpdData,
  ID = "ID",
  C = "CObs",
  EObs = "EObs",
  modelName = "model",
  workingDir = TempDir
)

saveModel(model)

loadModel(TempDir)
# }

Run the code above in your browser using DataLab