Use to create a PK/PD model with PD described by either constant, linear, or quadratic model
pklinearmodel(
isPopulation = TRUE,
parameterization = "Clearance",
absorption = "Intravenous",
numCompartments = 1,
isClosedForm = TRUE,
isTlag = FALSE,
hasEliminationComp = FALSE,
isFractionExcreted = FALSE,
isSaturating = FALSE,
infusionAllowed = FALSE,
isDuration = FALSE,
isSequential = FALSE,
isPkFrozen = FALSE,
hasEffectsCompartment = FALSE,
linearType = "Constant",
isLinearFrozen = FALSE,
data = NULL,
columnMap = TRUE,
modelName = "",
workingDir = "",
...
)NlmePmlModel object
Is this a population model TRUE or individual model FALSE?
Type of parameterization. Options are "Clearance", "Micro",
"Macro", or "Macro1".
Type of absorption. Options are "Intravenous", "FirstOrder",
"Gamma", "InverseGaussian", "Weibull" .
Value of either 1, 2, or 3.
Set to TRUE to convert model from a differential equation to close form.
Set to TRUE to add a lag time parameter to the model.
Set to TRUE to add an elimination compartment to the model.
Set to TRUE if elimination compartment (hasEliminationComp = TRUE)
contains a fraction excreted parameter.
Set to TRUE to use Michaelis-Menten kinetics for elimination.
Only applicable to models with paramteterization = "Clearance"
Set to TRUE if infusions allowed.
Set to TRUE if infusions use duration instead of rate
(must also set infusionAllowed = TRUE).
Set to TRUE to freeze PK fixed effects and convert
the corresponding random effects into covariates as well as remove the PK observed variable from the model.
Set to TRUE to freeze PK fixed effects and remove
the corresponding random effects as well as the PK observed variable from the model.
Set to TRUE to include an effect compartment into the model.
Type of PD model; Options are "Constant", "Linear", "Quadratic".
Set to TRUE to freeze PD fixed effects and remove
the corresponding random effects as well as the PD observed variable from the model.
Input dataset
If TRUE (default) column mapping arguments are required.
Set to FALSE to manually map columns after defining model using colMapping.
Model name for subdirectory created for model output in current working directory.
Working directory to run the model. Current working directory will be used
if workingDir not specified.
Arguments passed on to pkindirectmodel_MappingParameters
IDColumn mapping argument for input dataset column(s) that identify
individual data profiles. Only applicable to population models isPopulation = TRUE.
TimeColumn mapping argument that represents the input dataset column for the relative time used in a study and only applicable to time-based models.
A1Column mapping argument that represents the input dataset column for the amount of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous" and parameterization set
to either "Clearance","Micro", or "Macro"
Models with absorption set to either "Gamma", "InverseGaussian",
or "Weibull"
AaColumn mapping argument that represents the input dataset column
for the amount of drug administered and only applicable to models with absorption = "FirstOrder".
AColumn mapping argument that represents the input dataset column
for the amount of drug administered and only applicable to models with
absorption = "Intravenous" and parameterization = "Macro1".
A1_RateColumn mapping argument that represents the input dataset column for the rate of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous", infusionAllowed = TRUE
and parameterization set to either "Clearance","Micro" or "Macro"
Models with absorption set to either "Gamma", "InverseGaussian",
or "Weibull" and infusionAllowed = TRUE
A1_DurationColumn mapping argument that represents the input dataset column for the duration of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous", infusionAllowed = TRUE with
isDuration = TRUE and parameterization set to either "Clearance","Micro"
or "Macro"
Models with absorption set to either "Gamma", "InverseGaussian",
or "Weibull" and infusionAllowed = TRUE with isDuration = TRUE
Aa_RateColumn mapping argument that represents the input dataset column
for the rate of drug administered and only applicable to models with absorption = "FirstOrder",
infusionAllowed = TRUE.
Aa_DurationColumn mapping argument that represents the input dataset column
for the duration of drug administered and only applicable to models with absorption = "FirstOrder",
infusionAllowed = TRUE, and isDuration = TRUE.
A_RateColumn mapping argument that represents the input dataset column
for the rate of drug administered and only applicable to models with absorption = "Intravenous",
infusionAllowed = TRUE, and parameterization = "Macro1".
A_DurationColumn mapping argument that represents the input dataset column
for the duration of drug administered and only applicable to models with absorption = "Intravenous",
infusionAllowed = TRUE, isDuration = TRUE, and parameterization = "Macro1".
A1StripColumn mapping argument that represents the input dataset column
for the stripping dose and only applicable to models with parameterization = "Macro".
CObsColumn mapping argument that represents the input dataset column
for the observations of drug concentration in the central compartment and only applicable
to models with parameterization being either set to either "Clearance" or "Micro".
C1ObsColumn mapping argument that represents the input dataset column
for the observations of drug concentration in the central compartment and only applicable
to models with parameterization being either set to either "Macro" or "Macro1".
A0ObsColumn mapping argument that represents the input dataset column
for the observed amount of drug in the elimination compartment. (hasEliminationComp = TRUE).
EObsColumn mapping argument that represents the input dataset column for the observed drug effect.
nVIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nV.
nV2If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nV2.
nV3If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nV3.
nClIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nCl.
nCl2If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nCl2.
nCl3If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nCl3.
nKaIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nKa.
nAIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nA.
nAlphaIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nAlpha.
nBIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nB.
nBetaIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nBeta.
nCIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nC.
nGammaIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nGamma.
nKeIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nKe.
nK12If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nK12.
nK21If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nK21.
nK13If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nK13.
nK31If isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nK31.
nTlagIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nTlag.
nKmIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nKm.
nVmaxIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nVmax.
nFeIf isSequential = TRUE and isFractionExcreted = TRUE,
mapped to the input dataset column that lists the values for random effect nFe.
nMeanDelayTimeIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nMeanDelayTime.
nShapeParamIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nShapeParam.
nShapeParamMinusOneIf isSequential = TRUE, mapped to the input dataset column
that lists the values for random effect nShapeParamMinusOne.
Note that quoted and unquoted column names are supported. Please see colMapping.
model <- pklinearmodel(
parameterization = "Clearance",
linearType = "Constant",
data = pkpdData,
ID = "ID",
Time = "Time",
A1 = "Dose",
CObs = "CObs",
EObs = "EObs"
)
# View the model as well as its associated column mappings
print(model)
Run the code above in your browser using DataLab