Use to create a PK model
pkmodel(
isPopulation = TRUE,
parameterization = "Clearance",
absorption = "Intravenous",
numCompartments = 1,
isClosedForm = TRUE,
isTlag = FALSE,
hasEliminationComp = FALSE,
isFractionExcreted = FALSE,
isSaturating = FALSE,
infusionAllowed = FALSE,
isDuration = FALSE,
isStdevFrozen = FALSE,
data = NULL,
columnMap = TRUE,
modelName = "",
workingDir = "",
...
)NlmePmlModel object
Is this a population model TRUE or individual model FALSE?
Type of parameterization. Options are "Clearance", "Micro",
"Macro", or "Macro1".
Type of absorption. Options are "Intravenous", "FirstOrder",
"Gamma", "InverseGaussian", "Weibull" .
Value of either 1, 2, or 3.
Set to TRUE to convert model from a differential equation to close form.
Set to TRUE to add a lag time parameter to the model.
Set to TRUE to add an elimination compartment to the model.
Set to TRUE if elimination compartment (hasEliminationComp = TRUE)
contains a fraction excreted parameter.
Set to TRUE to use Michaelis-Menten kinetics for elimination.
Only applicable to models with paramteterization = "Clearance"
Set to TRUE if infusions allowed.
Set to TRUE if infusions use duration instead of rate
(must also set infusionAllowed = TRUE).
Set to TRUE to freeze value of standard deviation of residual error variable.
Input dataset
If TRUE (default) column mapping arguments are required.
Set to FALSE to manually map columns after defining model using colMapping.
Model name for subdirectory created for model output in current working directory.
Working directory to run the model. Current working directory will be used
if workingDir not specified.
Arguments passed on to pkmodel_MappingParameters
IDColumn mapping argument for input dataset column(s) that identify
individual data profiles. Only applicable to population models isPopulation = TRUE.
TimeColumn mapping argument that represents the input dataset column for the relative time used in a study and only applicable to time-based models.
A1Column mapping argument that represents the input dataset column for the amount of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous" and parameterization set
to either "Clearance","Micro", or "Macro"
Models with absorption set to either "Gamma",
"InverseGaussian", or "Weibull"
AaColumn mapping argument that represents the input dataset column
for the amount of drug administered and only applicable to models with absorption = "FirstOrder".
AColumn mapping argument that represents the input dataset column
for the amount of drug administered and only applicable to models with
absorption = "Intravenous" and parameterization = "Macro1".
A1_RateColumn mapping argument that represents the input dataset column for the rate of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous", infusionAllowed = TRUE
and parameterization set to either "Clearance","Micro" or "Macro"
Models with absorption set to either "Gamma", "InverseGaussian",
or "Weibull" and infusionAllowed = TRUE
A1_DurationColumn mapping argument that represents the input dataset column for the duration of drug administered. Only applicable to the following types of models:
Models with absorption = "Intravenous",infusionAllowed = TRUE
with isDuration = TRUE and parameterization set to either "Clearance",
"Micro" or "Macro"
Models with absorption set to either "Gamma", "InverseGaussian",
or "Weibull" and infusionAllowed = TRUE with isDuration = TRUE
Aa_RateColumn mapping argument that represents the input dataset column
for the rate of drug administered and only applicable to models with absorption = "FirstOrder",
infusionAllowed = TRUE.
Aa_DurationColumn mapping argument that represents the input dataset column
for the duration of drug administered and only applicable to models with absorption = "FirstOrder",
infusionAllowed = TRUE, and isDuration = TRUE.
A_RateColumn mapping argument that represents the input dataset column
for the rate of drug administered and only applicable to models with absorption = "Intravenous",
infusionAllowed = TRUE, and parameterization = "Macro1".
A_DurationColumn mapping argument that represents the input dataset column
for the duration of drug administered and only applicable to models with absorption = "Intravenous",
infusionAllowed = TRUE, isDuration = TRUE, and parameterization = "Macro1".
A1StripColumn mapping argument that represents the input dataset column
for the stripping dose and only applicable to models with parameterization = "Macro".
CObsColumn mapping argument that represents the input dataset column
for the observations of drug concentration in the central compartment and only applicable
to models with parameterization being either set to either "Clearance" or "Micro".
C1ObsColumn mapping argument that represents the input dataset column
for the observations of drug concentration in the central compartment and only applicable
to models with parameterization being either set to either "Macro" or "Macro1".
A0ObsColumn mapping argument that represents the input dataset column
for the observed amount of drug in the elimination compartment. (hasEliminationComp = TRUE).
Note that quoted and unquoted column names are supported. Please see colMapping.
model <- pkmodel(
parameterization = "Clearance",
numCompartments = 2,
data = pkData,
ID = "Subject",
Time = "Act_Time",
A1 = "Amount",
CObs = "Conc",
workingDir = tempdir()
)
# View the model as well as its associated column mappings
print(model)
Run the code above in your browser using DataLab