Learn R Programming

Certara.RsNLME (version 3.1.0.1)

print.NlmeParallelHost: Print an NlmeParallelHost Object

Description

Prints a summary of the configuration of an NlmeParallelHost object.

Usage

# S3 method for NlmeParallelHost
print(x, ...)

Value

NULL. This function is called for its side effect of printing to the console.

Arguments

x

An NlmeParallelHost object to print.

...

Additional arguments passed to the print function.

Examples

Run this code
host <- NlmeParallelHost(
  sharedDirectory = "~/shared/",
  installationDirectory = "~/nlme/",
  hostName = "my_host",
  machineName = "192.168.1.100",
  hostType = "RHEL",
  numCores = 8,
  isLocal = FALSE,
  rLocation = "/usr/bin/R",
  scriptPath = "/path/to/script.R",
  userAuthentication =
    NlmeUserAuthentication(userName = "myuser", userPassword = "mypassword"),
  parallelMethod = NlmeParallelMethod("SGE_MPI")
)

print(host)

Run the code above in your browser using DataLab