Learn R Programming

Certara.RsNLME (version 3.1.0.1)

saveModel: Save model object to .rda file

Description

Saves the model, engine, and host objects to a single model.rda file in model's working directory. If no working directory exists it will be created by default.

Usage

saveModel(model, engine = NULL, host = NULL)

Value

NULL

Arguments

model

NlmePmlModel object

engine

Optional engine parameters to save with model

host

Optional host to save with model

Examples

Run this code
# \donttest{
model <- emaxmodel(
  checkBaseline = TRUE,
  checkFractional = TRUE,
  checkInhibitory = TRUE,
  data = pkpdData,
  ID = "ID",
  C = "CObs",
  EObs = "EObs",
  workingDir = tempdir()
)

saveModel(model)
# }

Run the code above in your browser using DataLab