Learn R Programming

Certara.RsNLME (version 3.1.0.1)

structuralParameterNames: Get structural parameter names

Description

Returns character vector of structural parameter names for model object.

Usage

structuralParameterNames(model, omitEmpties = TRUE)

Value

Character vector of structural parameter names defined in model

Arguments

model

Object of class NlmePmlModel

omitEmpties

Set to TRUE to omit empty names

Examples

Run this code
model <- pkemaxmodel(columnMap = FALSE)
stparms <- structuralParameterNames(model)

Run the code above in your browser using DataLab