textualmodel: Create a textual model object
Description
Use to create an empty model object and optionally supply location of .mdl file to initialize model with PML statements.
Usage
textualmodel(modelName = "", workingDir = "", data, mdl = NULL)
Arguments
- modelName
Model name to create subdirectory for model output in current working directory.
- workingDir
Working directory to run the model. Current working directory will be used if workingDir not specified.
- data
Input dataset
- mdl
File path specifying location of test.mdl file
Examples
Run this code# \donttest{
model <- textualmodel(data = pkData)
# }
Run the code above in your browser using DataLab