Adds reset instructions to the model
addReset(.Object, low, hi, Reset = NULL)# S4 method for NlmePmlModel
addReset(.Object, low, hi, Reset = NULL)
Depends on the specific methods
Returns the 'NlmePmlModel' object with updated reset information and definitions.
An 'NlmePmlModel' object to which you want to add reset instructions.
Lower value of reset range.
Upper value of reset range.
Name of reset column in input data set for column mapping. The default is NULL.
addReset(NlmePmlModel): Method for the 'NlmePmlModel' class
This method adds reset instructions to the NlmePmlModel object. It updates the reset information, checks column mappings if input data is not null, and adds a reset definition to user-defined extra definitions.