Is this a population model TRUE or individual model FALSE?
type
Model type. Options are "Constant", "Linear", "Quadratic".
data
Input dataset
columnMap
If TRUE (default) column mapping arguments are required.
Set to FALSE to manually map columns after defining model using colMapping.
modelName
Model name for subdirectory created for model output in current working directory.
workingDir
Working directory to run the model. Current working directory will be used
if workingDir not specified.
...
Arguments passed on to linearmodel_MappingParameters
ID
Column mapping argument for input dataset column(s)
that identify individual data profiles. Only applicable to population models
isPopulation = TRUE.
C
Column mapping argument that represents
the input dataset column for the independent variable that is treated
as a covariate during the estimation/simulation process.
EObs
Column mapping argument that represents
the input dataset column for the observed drug effect
(i.e., the dependent variable).
Column mapping
Note that quoted and unquoted column names are supported. Please see colMapping.