powered by
Returns character vector of structural parameter names for model object.
structuralParameterNames(model, omitEmpties = TRUE)
Character vector of structural parameter names defined in model
Object of class NlmePmlModel
NlmePmlModel
Set to TRUE to omit empty names
TRUE
model <- pkemaxmodel(columnMap = FALSE) stparms <- structuralParameterNames(model)
Run the code above in your browser using DataLab